@@ -3,16 +3,15 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Calculate date-time operations
 
-our $VERSION = '0.0304';
+our $VERSION = '0.0400';
 
 use strict;
 use warnings;
 
 use base qw(Bot::BasicBot::Pluggable);
 
-use Date::Manip;
 use DateTime;
-use DateTime::Format::DateParse;
+use DateTime::Format::Natural;
 
 
 
@@ -84,7 +83,7 @@ sub said {
         }
         # Exit IRC
         elsif ( $arguments->{body} =~ /^leave$/ ) {
-            $self->shutdown( $self->quit_message() );
+            $self->shutdown( $self->quit_message );
             exit;
         }
 
@@ -104,9 +103,8 @@ sub _capture {
 
 sub _to_dt {
     my($capture) = @_;
-    my $format = '%Y-%m-%dT%H:%M:%S';
-    my $stamp = UnixDate( $capture, $format );
-    my $dt = DateTime::Format::DateParse->parse_datetime($stamp);
+    my $parser = DateTime::Format::Natural->new;
+    my $dt = $parser->parse_datetime($capture);
     return $dt;
 }
 
@@ -125,7 +123,7 @@ Bot::BasicBot::Pluggable::Module::DateTimeCalc - Calculate date-time operations
 
 =head1 VERSION
 
-version 0.0304
+version 0.0400
 
 =head1 SYNOPSIS
 
@@ -138,7 +136,7 @@ version 0.0304
     name        => 'Your Name Bot',
     ignore_list => [qw/other_bot some_fool/],
   );
-  $bot->run();
+  $bot->run;
 
 =head1 DESCRIPTION
 
@@ -147,24 +145,24 @@ operations.
 
 This bot is coded to only respond when directly addressed, btw.
 
-Since this module uses L<Date::Manip>, many different date-time formats are
-supported.
+Since this module uses L<DateTime::Format::Natural>, many different
+date-time formats are supported.
 
 =head1 METHODS
 
-=head2 new()
+=head2 new
 
 Create a new C<Bot::BasicBot::Pluggable::Module::DateTimeCalc> object.
 
-=head2 help()
+=head2 help
 
 Show the keyword help message.
 
-=head2 said()
+=head2 said
 
 Process the date-time calculations.
 
-=head2 run()
+=head2 run
 
 Start the process and connect to the IRC.
 
@@ -223,11 +221,9 @@ Exit the IRC and the running process.
 
 L<Bot::BasicBot::Pluggable>
 
-L<Date::Manip>
-
 L<DateTime>
 
-L<DateTime::Format::DateParse>
+L<DateTime::Format::Natural>
 
 =head1 AUTHOR
 
